[Openmp-commits] [openmp] 9bcef58 - [OpenMP] Fix building for windows after adding omp_calloc

Martin Storsjö via Openmp-commits openmp-commits at lists.llvm.org
Sun Nov 15 11:33:03 PST 2020


Author: Martin Storsjö
Date: 2020-11-15T21:32:38+02:00
New Revision: 9bcef58b63776c490fd902290f0efc580e3970bc

URL: https://github.com/llvm/llvm-project/commit/9bcef58b63776c490fd902290f0efc580e3970bc
DIFF: https://github.com/llvm/llvm-project/commit/9bcef58b63776c490fd902290f0efc580e3970bc.diff

LOG: [OpenMP] Fix building for windows after adding omp_calloc

Differential Revision: https://reviews.llvm.org/D91478

Added: 
    

Modified: 
    openmp/runtime/tools/generate-def.pl

Removed: 
    


################################################################################
diff  --git a/openmp/runtime/tools/generate-def.pl b/openmp/runtime/tools/generate-def.pl
index 0298d723c3a3..b245387c0fc0 100755
--- a/openmp/runtime/tools/generate-def.pl
+++ b/openmp/runtime/tools/generate-def.pl
@@ -108,8 +108,8 @@ (\%)
     foreach my $entry ( keys( %$entries ) ) {
         if ( not $entries->{ $entry }->{ obsolete } ) {
             my $ordinal = $entries->{ $entry }->{ ordinal };
-            # omp_alloc and omp_free are C/C++ only functions, skip "1000+ordinal" for them
-            if ( $entry =~ m{\A[ok]mp_} and $entry ne "omp_alloc" and $entry ne "omp_free" ) {
+            # omp_alloc, omp_calloc and omp_free are C/C++ only functions, skip "1000+ordinal" for them
+            if ( $entry =~ m{\A[ok]mp_} and $entry ne "omp_alloc" and $entry ne "omp_calloc" and $entry ne "omp_free" ) {
                 if ( not defined( $ordinal ) ) {
                     runtime_error(
                         "Bad entry \"$entry\": ordinal number is not specified."


        


More information about the Openmp-commits mailing list